@@ -1,13 +1,14 @@
-# @Author:  Felix Kramer
-# @Date:   2021-05-22T13:11:37+02:00
-# @Email:  kramer@mpi-cbg.de
-# @Project: go-with-the-flow
-# @Last modified by:    Felix Kramer
-# @Last modified time: 2021-11-07T15:54:51+01:00
-# @License: MIT
+# @Author: Felix Kramer <kramer>
+# @Date:   24-02-2022
+# @Email:  felixuwekramer@proton.me
+# @Last modified by:   kramer
+# @Last modified time: 08-07-2022
+
+
 import networkx as nx
 import numpy as np
 
+
 # construct a non-trivial,  periodic 3d embedding
 def init_graph_from_crystal(crystal_type, periods):
 
@@ -15,8 +16,11 @@ def init_graph_from_crystal(crystal_type, periods):
     Initialize a spatially embedded graph, with based on crystal lattice.
 
     Args:
-        crystal_type (string): The type of crystal skeleton (default, simple, chain, bcc, fcc, diamond, laves, square, hexagonal, trigonal_planar).
-        periods (int): Repetition number of the lattice's unit cell.
+        crystal_type (string):\n
+            The type of crystal skeleton (default, simple, chain, bcc, fcc,
+            diamond, laves, square, hexagonal, trigonal_planar).
+        periods (int):\n
+            Repetition number of the lattice's unit cell.
 
     Returns:
         nx.Graph: A networkx graph.
@@ -33,28 +37,32 @@ def init_graph_from_crystal(crystal_type, periods):
         'laves': NetworkxLaves,
         'square': NetworkxSquare,
         'hexagonal': NetworkxHexagonal,
-        'trigonal_planar': NetworkxTrigonalPlanar,
+        'triagonal_planar': NetworkxTriagonalPlanar,
         }
 
     if crystal_type in choose_constructor_option:
-            crystal = choose_constructor_option[crystal_type](periods)
+        crystal = choose_constructor_option[crystal_type](periods)
 
-    else :
+    else:
         print('Warning, crystal type unknown, set default: simple')
         crystal = choose_constructor_option['default'](1)
 
     return crystal.G
 
+
 def init_graph_from_asymCrystal(crystal_type, periodsZ, periodsXY):
 
     """
     Initialize a spatially embedded graph, with based on an asymmetric
-     crystal lattice.
+    crystal lattice.
 
     Args:
-        crystal_type (string): The type of crystal skeleton (trigonal_stack).
-        periodsZ (int): Vertical repetition number of the lattice's unit cell.
-        periodsXY (int): Lateral repetition number of the lattice's unit cell.
+        crystal_type (string):\n
+            The type of crystal skeleton (trigonal_stack).
+        periodsZ (int):\n
+            Vertical repetition number of the lattice's unit cell.
+        periodsXY (int):\n
+            Lateral repetition number of the lattice's unit cell.
 
     Returns:
         nx.Graph: A networkx graph.
@@ -62,18 +70,19 @@ def init_graph_from_asymCrystal(crystal_type, periodsZ, periodsXY):
     """
 
     choose_constructor_option = {
-        'trigonal_stack': networkx_trigonal_stack,
+        'trigonal_stack': NetworkxTriagonalStack,
         }
 
     if crystal_type in choose_constructor_option:
-            crystal = choose_constructor_option[crystal_type](periodsZ, periodsXY)
+        crystal = choose_constructor_option[crystal_type](periodsZ, periodsXY)
 
-    else :
+    else:
         print('Warning, crystal type unknown, set default: trigonal_stack')
-        crystal = choose_constructor_option['default'](2,2)
+        crystal = choose_constructor_option['default'](2, 2)
 
     return crystal.G
 
+
 class NetworkxCrystal():
 
     """
@@ -82,10 +91,14 @@ class NetworkxCrystal():
     Attributes
     ----------
 
-        G (nx.Graph): An internal networkx graph variable.
-        dict_cells (dictionary): A dictionary of the current cells.
-        lattice_constant (float): Scale for the lattice. spacing
-        translation_length (float): Scale for the translational offset.
+        G (nx.Graph):\n
+            An internal networkx graph variable.
+        dict_cells (dictionary):\n
+            A dictionary of the current cells.
+        lattice_constant (float):\n
+            Scale for the lattice. spacing
+        translation_length (float):\n
+            Scale for the translational offset.
 
     """
 
@@ -93,11 +106,11 @@ class NetworkxCrystal():
 
         """
         A constructor for crystal objects, setting default values
-         for the interal graph objects and geometry
+        for the interal graph objects and geometry
         """
 
         self.G = nx.Graph()
-        self.dict_cells = {  }
+        self.dict_cells = {}
         self.lattice_constant = 1
         self.translation_length = 1
 
@@ -108,8 +121,10 @@ class NetworkxCrystal():
         Return a networkx graph, initialzed from given unit cell and offset.
 
         Args:
-            t (ndarray): A translational offset for the lattice.
-            T (nx.Graph): A networkx graph, unit cell.
+            t (ndarray):\n
+                A translational offset for the lattice.
+            T (nx.Graph):\n
+                A networkx graph, unit cell.
 
         Returns:
             nx.Graph: A simple, periodic Graph.
@@ -125,17 +140,20 @@ class NetworkxCrystal():
     def periodic_cell_structure(self, cell, num_periods):
 
         """
-        Set the internal graph variable by periodically repeating the chosen unitcell type.
+        Set the internal graph variable by periodically repeating the chosen
+        unitcell type.
 
         Args:
-            cell (nx.Graph): A networkx graph, unit cell.
-            num_periods (int): Repetition number for the unit cells.
+            cell (nx.Graph):\n
+                A networkx graph, unit cell.
+            num_periods (int):\n
+                Repetition number for the unit cells.
 
         """
 
         DL = nx.Graph()
 
-        if type(num_periods) is not int :
+        if type(num_periods) is not int:
             periods = [range(num_periods[i]) for i in range(3)]
         else:
             periods = [range(num_periods) for i in range(3)]
@@ -154,17 +172,15 @@ class NetworkxCrystal():
                 q = DL.nodes[tuple(m)]['pos']
                 dist = np.linalg.norm(p-q)
                 if dist == self.lattice_constant:
-                    mn = (DL.nodes[tuple(n)]['pos'], DL.nodes[tuple(m)]['pos'])
                     DL.add_edge(tuple(n), tuple(m))
 
         dict_nodes = {}
         for idx_n, n in enumerate(DL.nodes()):
             self.G.add_node(idx_n, pos=DL.nodes[n]['pos'])
-            dict_nodes.update({n:idx_n})
+            dict_nodes.update({n: idx_n})
         for idx_e, e in enumerate(DL.edges()):
             u, v = dict_nodes[e[0]], dict_nodes[e[1]]
-            uv = (DL.nodes[e[0]]['pos'], DL.nodes[e[1]]['pos'])
-            self.G.add_edge(u, v )
+            self.G.add_edge(u, v)
 
         self.dict_cubes = {}
         dict_aux = {}
@@ -177,6 +193,8 @@ class NetworkxCrystal():
                 for v in n_list[1:]:
                     if self.G.has_edge(u, v):
                         self.dict_cubes[k].add_edge(u, v)
+
+
 # 3D
 class NetworkxSimple(NetworkxCrystal):
 
@@ -189,7 +207,7 @@ class NetworkxSimple(NetworkxCrystal):
 
         """
         A constructor for simple cubic crystal objects, setting default values
-         for the interal graph objects and geometry
+        for the interal graph objects and geometry
         """
 
         super(NetworkxSimple, self).__init__()
@@ -197,14 +215,15 @@ class NetworkxSimple(NetworkxCrystal):
         self.translation_length = 1.
         self.simple_cubic_lattice(num_periods)
 
-    #construct full cubic grid as skeleton
+    # construct full cubic grid as skeleton
     def simple_unit_cell(self):
 
         """
         Return a networkx graph of the simbple cubic unit cell.
 
         Returns:
-            nx.Graph: A  networkx graph.
+            nx.Graph:\n
+                A  networkx graph.
 
         """
 
@@ -222,13 +241,15 @@ class NetworkxSimple(NetworkxCrystal):
         Set the internal graph as simple cubic lattice.
 
         Args:
-            num_periods (int): Repetition number for the unit cell.
+            num_periods (int):\n
+                Repetition number for the unit cell.
 
         """
 
         D = self.simple_unit_cell()
         self.periodic_cell_structure(D, num_periods)
 
+
 class NetworkxChain(NetworkxCrystal):
 
     """
@@ -240,7 +261,7 @@ class NetworkxChain(NetworkxCrystal):
 
         """
         A constructor for chain objects, setting default values
-         for the interal graph objects and geometry
+        for the interal graph objects and geometry
         """
 
         super(NetworkxChain, self).__init__()
@@ -252,17 +273,18 @@ class NetworkxChain(NetworkxCrystal):
         Set the internal graph as a simple 1D chain.
 
         Args:
-            num_periods (int): Length of the chain.
+            num_periods (int):\n
+                Length of the chain.
 
         """
 
-        #construct single box
+        # construct single box
         for i in range(num_periods):
             self.G.add_node(i, pos=np.array([i, 0, 0]))
         for i in range(num_periods-1):
-            df = (self.G.nodes[i+1]['pos'], self.G.nodes[i]['pos'])
             self.G.add_edge(i+1, i)
 
+
 class NetworkxBcc(NetworkxCrystal):
 
     """
@@ -274,7 +296,7 @@ class NetworkxBcc(NetworkxCrystal):
 
         """
         A constructor for simple bcc crystal objects, setting default values
-         for the interal graph objects and geometry
+        for the interal graph objects and geometry
         """
         super(NetworkxBcc, self).__init__()
         self.lattice_constant = np.sqrt(3.)/2.
@@ -287,7 +309,8 @@ class NetworkxBcc(NetworkxCrystal):
         Return a networkx graph of the simple bcc unit cell.
 
         Returns:
-            nx.Graph: A  networkx graph.
+            nx.Graph:\n
+                A  networkx graph.
 
         """
 
@@ -295,7 +318,7 @@ class NetworkxBcc(NetworkxCrystal):
         for i in [0, 1]:
             for j in [0, 1]:
                 for k in [0, 1]:
-                    D.add_node(tuple((i, j, k)), pos = np.array([i, j, k]))
+                    D.add_node(tuple((i, j, k)), pos=np.array([i, j, k]))
         D.add_node(tuple((0.5, 0.5, 0.5)), pos=np.array([0.5, 0.5, 0.5]))
 
         return D
@@ -306,14 +329,16 @@ class NetworkxBcc(NetworkxCrystal):
         Set the internal graph as simple bcc lattice.
 
         Args:
-            num_periods (int): Repetition number for the unit cell.
+            num_periods (int):\n
+                Repetition number for the unit cell.
 
         """
 
-        #construct single box
+        # construct single box
         D = self.bcc_unit_cell()
         self.periodic_cell_structure(D, num_periods)
 
+
 class NetworkxFcc(NetworkxCrystal):
 
     """
@@ -325,7 +350,7 @@ class NetworkxFcc(NetworkxCrystal):
 
         """
         A constructor for simple fcc crystal objects, setting default values
-         for the interal graph objects and geometry
+        for the interal graph objects and geometry
         """
         super(NetworkxFcc, self).__init__()
         self.lattice_constant = np.sqrt(2.)/2.
@@ -338,7 +363,8 @@ class NetworkxFcc(NetworkxCrystal):
         Return a networkx graph of the simple fcc unit cell.
 
         Returns:
-            nx.Graph: A  networkx graph.
+            nx.Graph:\n
+                A  networkx graph.
 
         """
 
@@ -362,13 +388,15 @@ class NetworkxFcc(NetworkxCrystal):
         Set the internal graph as simple fcc lattice.
 
         Args:
-            num_periods (int): Repetition number for the unit cell.
+            num_periods (int):\n
+                Repetition number for the unit cell.
 
         """
 
         D = self.fcc_unit_cell()
         self.periodic_cell_structure(D, num_periods)
 
+
 class NetworkxDiamond(NetworkxCrystal):
 
     """
@@ -379,7 +407,7 @@ class NetworkxDiamond(NetworkxCrystal):
     def __init__(self, num_periods):
         """
         A constructor for diamond crystal objects, setting default values
-         for the interal graph objects and geometry
+        for the interal graph objects and geometry
         """
         super(NetworkxDiamond, self).__init__()
         self.lattice_constant = np.sqrt(3.)/2.
@@ -392,7 +420,8 @@ class NetworkxDiamond(NetworkxCrystal):
         Return a networkx graph of the dioamond unit cell.
 
         Returns:
-            nx.Graph: A  networkx graph.
+            nx.Graph:\n
+                A  networkx graph.
 
         """
 
@@ -403,8 +432,11 @@ class NetworkxDiamond(NetworkxCrystal):
         T[0].add_node((1, 0, 1), pos=np.array([1, 0, 1]))
         T[0].add_node((0, 1, 1), pos=np.array([0, 1, 1]))
         T[0].add_node((0.5, 0.5, 0.5), pos=np.array([0.5, 0.5, 0.5]))
-        translation = [np.array([1, 1, 0]), np.array([1, 0, 1]),
-         np.array([0, 1, 1])]
+        translation = [
+            np.array([1, 1, 0]),
+            np.array([1, 0, 1]),
+            np.array([0, 1, 1])
+            ]
         for i, t in enumerate(translation):
             for n in T[0].nodes():
                 T[i+1].add_node(tuple(n+t), pos=T[0].nodes[n]['pos']+t)
@@ -419,13 +451,15 @@ class NetworkxDiamond(NetworkxCrystal):
         Set the internal graph as diamond lattice.
 
         Args:
-            num_periods (int): Repetition number for the unit cell.
+            num_periods (int):\n
+                Repetition number for the unit cell.
 
         """
 
         D = self.diamond_unit_cell()
         self.periodic_cell_structure(D, num_periods)
 
+
 class NetworkxLaves(NetworkxCrystal):
 
     """
@@ -436,7 +470,7 @@ class NetworkxLaves(NetworkxCrystal):
     def __init__(self, num_periods):
         """
         A constructor for laves crystal objects, setting default values
-         for the interal graph objects and geometry
+        for the interal graph objects and geometry.
         """
         super(NetworkxLaves, self).__init__()
         self.lattice_constant = 2.
@@ -448,21 +482,30 @@ class NetworkxLaves(NetworkxCrystal):
         Set the internal graph as laves lattice.
 
         Args:
-            num_periods (int): Repetition number for the unit cell.
+            num_periods (int):\n
+                Repetition number for the unit cell.
 
         """
 
-        #construct single box
-        counter = 0
+        # construct single box
         G_aux = nx.Graph()
-        if type(num_periods) is not int :
+        if type(num_periods) is not int:
             periods = [range(num_periods[i]) for i in range(3)]
         else:
             periods = [range(num_periods) for i in range(3)]
 
-        fundamental_points = [[0, 0, 0], [1, 1, 0], [1, 2, 1], [0, 3, 1],
-         [2, 2, 2], [3, 3, 2], [3, 0, 3], [2, 1, 3]]
-        for l, fp in enumerate(fundamental_points):
+        fundamental_points = [
+            [0, 0, 0],
+            [1, 1, 0],
+            [1, 2, 1],
+            [0, 3, 1],
+            [2, 2, 2],
+            [3, 3, 2],
+            [3, 0, 3],
+            [2, 1, 3]
+        ]
+
+        for fp in fundamental_points:
             for i in periods[0]:
                 for j in periods[1]:
                     for k in periods[2]:
@@ -473,44 +516,45 @@ class NetworkxLaves(NetworkxCrystal):
         list_nodes = list(G_aux.nodes())
         self.G = nx.Graph()
         H = nx.Graph()
-        points_G = [G_aux.nodes[n]['pos'] for i, n in enumerate(G_aux.nodes()) ]
-        for i, n in enumerate(G_aux.nodes()) :
+
+        for i, n in enumerate(G_aux.nodes()):
             H.add_node(n, pos=G_aux.nodes[n]['pos'])
+
         for i, n in enumerate(list_nodes[:-1]):
-              for j, m in enumerate(list_nodes[(i+1):]):
+            for j, m in enumerate(list_nodes[(i+1):]):
 
                 v = np.subtract(n, m)
                 dist = np.dot(v, v)
                 if dist == self.lattice_constant:
-                    mn = (G_aux.nodes[n]['pos'], G_aux.nodes[m]['pos'])
                     H.add_edge(n, m)
 
         dict_nodes = {}
         for idx_n, n in enumerate(H.nodes()):
             self.G.add_node(idx_n, pos=H.nodes[n]['pos'])
-            dict_nodes.update({n:idx_n})
+            dict_nodes.update({n: idx_n})
 
         for idx_e, e in enumerate(H.edges()):
-            u,v = dict_nodes[e[0]], dict_nodes[e[1]]
-            uv = (H.nodes[e[0]]['pos'], H.nodes[e[1]]['pos'])
-            self.G.add_edge(u,v)
+            u, v = dict_nodes[e[0]], dict_nodes[e[1]]
+            self.G.add_edge(u, v)
+
 
 class NetworkxTriagonalStack(NetworkxCrystal):
 
     """
-    A derived class for spatial, stacked, triangulated graphs, contained in hexagonal shapes.
+    A derived class for spatial, stacked, triangulated graphs, contained in
+    hexagonal shapes.
 
     """
 
     def __init__(self, stacks, tiling_factor):
         """
-        A constructor for stacked, triangulated crystal objects, setting default values
-         for the interal graph objects and geometry
+        A constructor for stacked, triangulated crystal objects, setting
+        default values for the interal graph objects and geometry.
         """
         super(NetworkxTriagonalStack, self).__init__()
         self.triangulated_hexagon_stack(stacks, tiling_factor)
 
-    #define crosslinking procedure between the generated single-layers
+    # define crosslinking procedure between the generated single-layers
     def crosslink_stacks(self):
 
         """
@@ -520,22 +564,21 @@ class NetworkxTriagonalStack(NetworkxCrystal):
         for i, n in enumerate(self.G.nodes()):
             self.G.nodes[n]['label'] = i
 
-        if self.stacks > 1 :
+        if self.stacks > 1:
 
-            labels_n  =  nx.get_node_attributes(self.G, 'label')
-            sorted_label_n_list = sorted(labels_n , key = labels_n.__getitem__)
+            labels_n = nx.get_node_attributes(self.G, 'label')
+            sorted_label_n_list = sorted(labels_n, key=labels_n.__getitem__)
 
             for n in sorted_label_n_list:
-                if n[2]!= self.stacks-1:
+                if n[2] != self.stacks-1:
 
                     u = (n[0], n[1], n[2])
                     v = (n[0], n[1], n[2]+1)
-                    p1 = self.G.nodes[u]['pos']
-                    p2 = self.G.nodes[v]['pos']
 
                     self.G.add_edge(u, v)
 
-    # auxillary function,  construct triangulated hex grid upper and lower wings
+    # auxillary function,  construct triangulated hex grid upper and lower
+    # wings
     def construct_spine_stack(self, z, n):
 
         """
@@ -543,8 +586,10 @@ class NetworkxTriagonalStack(NetworkxCrystal):
          the internal graph and set spine length internally.
 
         Args:
-            z (float): The current stack indicator.
-            n (int): Length of the hexagon's outer sites.
+            z (float):\n
+                The current stack indicator.
+            n (int):\n
+                Length of the hexagon's outer sites.
 
         """
 
@@ -555,78 +600,80 @@ class NetworkxTriagonalStack(NetworkxCrystal):
             self.G.add_node((m+1, 0, z), pos=((m+1), 0., z))
             u = (m, 0, z)
             v = (m+1, 0, z)
-            uv = (self.G.nodes[u]['pos'], self.G.nodes[v]['pos'])
 
             self.G.add_edge(u, v)
 
     def construct_wing_stack(self, z, a, n):
 
         """
-        Generate new nodes and connections from the spines for each stacked hexagon.
+        Generate new nodes and connections from the spines for each stacked
+        hexagon.
 
         Args:
-            z (float): The current stack indicator.
-            a (int): +-1, setting the currently constructed hemisphere.
-            n (int): Length of the hexagon's outer sites.
+            z (float):\n
+                The current stack indicator.
+            a (int):\n
+                +-1, setting the currently constructed hemisphere.
+            n (int):\n
+                Length of the hexagon's outer sites.
 
         """
 
         for m in range(n-1):
-            #m-th floor
+            # m-th floor
             floor_m_nodes = self.spine-(m+1)
 
             u = (0, a*(m+1), z)
             v = (0, a*m, z)
             w = (1, a*m, z)
 
-            self.G.add_node(u, pos = ((m+1)/2., a*(np.sqrt(3.)/2.)*(m+1), z))
-            uv = (self.G.nodes[u]['pos'], self.G.nodes[v]['pos'])
-            vw = (self.G.nodes[u]['pos'], self.G.nodes[w]['pos'])
+            self.G.add_node(u, pos=((m+1)/2., a*(np.sqrt(3.)/2.)*(m+1), z))
+
             self.G.add_edge(u, v)
             self.G.add_edge(u, w)
 
             for p in range(floor_m_nodes):
-                #add 3-junctions
+                # add 3-junctions
                 u = (p+1, a*(m+1), z)
                 v = (p+1, a*m, z)
                 w = (p+2, a*m, z)
                 x = (p, a*(m+1), z)
 
                 ps = (((p+1)+(m+1)/2.), a*(np.sqrt(3.)/2.)*(m+1), z)
-                self.G.add_node(u, pos = ps)
-
-                uv = (self.G.nodes[u]['pos'], self.G.nodes[v]['pos'])
-                vw = (self.G.nodes[v]['pos'], self.G.nodes[w]['pos'])
-                ux = (self.G.nodes[u]['pos'], self.G.nodes[x]['pos'])
+                self.G.add_node(u, pos=ps)
 
                 self.G.add_edge(u, v)
                 self.G.add_edge(u, w)
                 self.G.add_edge(u, x)
 
-    #construct full triangulated hex grids as skeleton of a stacked structure
+    # construct full triangulated hex grids as skeleton of a stacked structure
     def triangulated_hexagon_stack(self, stacks, num_periods):
 
         """
-        Set the internal graph as stacked, triangulated lattice, contained in hexagonal shapes.
+        Set the internal graph as stacked, triangulated lattice, contained in
+        hexagonal shapes.
 
         Args:
-            stacks (int): The number of layers.
-            num_periods (int): Length of the hexagon's spine.
+            stacks (int):\n
+                The number of layers.
+            num_periods (int):\n
+                Length of the hexagon's spine.
 
         """
 
         self.stacks = stacks
         for z in range(self.stacks):
 
-            #construct spine for different levels of lobule
+            # construct spine for different levels of lobule
             self.construct_spine_stack(z, num_periods)
 
-            #construct lower/upper halfspace
+            # construct lower/upper halfspace
             self.construct_wing_stack(z, -1,  num_periods)
             self.construct_wing_stack(z,  1,  num_periods)
 
         self.crosslink_stacks()
 
+
 # 2D
 class NetworkxSquare(NetworkxCrystal):
 
@@ -639,7 +686,7 @@ class NetworkxSquare(NetworkxCrystal):
 
         """
         A constructor for simple tiled crystal objects, setting default values
-         for the interal graph objects and geometry
+        for the interal graph objects and geometry
         """
         super(NetworkxSquare, self).__init__()
         self.square_grid(tiling_factor)
@@ -651,7 +698,7 @@ class NetworkxSquare(NetworkxCrystal):
 
         """
 
-        if type(num_periods) is not int :
+        if type(num_periods) is not int:
             a = [range(0, num_periods[0]+1), range(0, num_periods[1]+1)]
         else:
             a = [range(0, num_periods+1), range(0, num_periods+1)]
@@ -670,11 +717,11 @@ class NetworkxSquare(NetworkxCrystal):
                 dict_d[(n, m)] = np.linalg.norm(p-q)
 
         for nm in dict_d:
-            if dict_d[nm] <=  threshold:
-                dnm = [self.G.nodes[nm[0]]['pos'], self.G.nodes[nm[1]]['pos']]
+            if dict_d[nm] <= threshold:
                 self.G.add_edge(*nm)
 
-class NetworkxTrigonalPlanar(NetworkxCrystal):
+
+class NetworkxTriagonalPlanar(NetworkxCrystal):
 
     """
     A derived class for spatial, planar triangulated graphs.
@@ -683,25 +730,29 @@ class NetworkxTrigonalPlanar(NetworkxCrystal):
 
     def __init__(self,  tiling_factor):
         """
-        A constructor for a planar triangulated crystal objects, setting default values
-         for the interal graph objects and geometry
+        A constructor for a planar triangulated crystal objects, setting
+        default values for the interal graph objects and geometry
         """
         super(NetworkxTriagonalPlanar, self).__init__()
         self.triangulated_hexagon_lattice(tiling_factor)
-    #I) construct and define one-layer hex
-    # auxillary function,  construct triangulated hex grid upper and lower wings
+    # I) construct and define one-layer hex
+    # auxillary function,  construct triangulated hex grid upper and lower
+    # wings
+
     def construct_wing(self, a, n):
 
         """
         Generate new nodes and connections from the spines of the hexagon.
 
         Args:
-            a (int): +-1, setting the currently constructed hemisphere.
-            n (int): Length of the hexagon's outer sites.
+            a (int):\n
+                +-1, setting the currently constructed hemisphere.
+            n (int):\n
+                Length of the hexagon's outer sites.
 
         """
         for m in range(n-1):
-            #m-th floor
+            # m-th floor
             floor_m_nodes = self.spine - (m+1)
 
             u = (0, a*(m+1))
@@ -710,13 +761,11 @@ class NetworkxTrigonalPlanar(NetworkxCrystal):
             ps = np.array([(m+1)/2., a*(np.sqrt(3.)/2.)*(m+1)])
 
             self.G.add_node(u, pos=ps)
-            uv = (self.G.nodes[u]['pos'], self.G.nodes[v]['pos'])
-            uw = (self.G.nodes[u]['pos'], self.G.nodes[w]['pos'])
             self.G.add_edge(u, v)
             self.G.add_edge(u, w)
 
             for p in range(floor_m_nodes):
-                #add 3-junctions
+                # add 3-junctions
                 u = (p+1, a*(m+1))
                 v = (p+1, a*m)
                 w = (p+2, a*m)
@@ -725,25 +774,23 @@ class NetworkxTrigonalPlanar(NetworkxCrystal):
 
                 self.G.add_node(u, pos=ps)
 
-                uv = (self.G.nodes[u]['pos'], self.G.nodes[v]['pos'])
-                uw = (self.G.nodes[u]['pos'], self.G.nodes[w]['pos'])
-                ux = (self.G.nodes[u]['pos'], self.G.nodes[x]['pos'])
                 self.G.add_edge(u, v)
                 self.G.add_edge(u, w)
                 self.G.add_edge(u, x)
 
-    #construct full triangulated hex grid as skeleton
+    # construct full triangulated hex grid as skeleton
     def triangulated_hexagon_lattice(self, n):
 
         """
         Generate new nodes and connections for the spine of the hexagon.
 
         Args:
-            n (int): Length of the hexagon's outer sites.
+            n (int):\n
+                Length of the hexagon's outer sites.
 
         """
 
-        #construct spine
+        # construct spine
         self.spine = 2*(n-1)
         self.G.add_node((0, 0), pos=np.array([0., 0.]))
 
@@ -751,45 +798,44 @@ class NetworkxTrigonalPlanar(NetworkxCrystal):
 
             self.G.add_node((m+1, 0), pos=np.array([(m+1), 0.]))
             u, v = (m, 0), (m+1, 0)
-            uv = (self.G.nodes[u]['pos'], self.G.nodes[v]['pos'])
-            self.G.add_edge( u, v)
+            self.G.add_edge(u, v)
 
-        #construct lower/upper halfspace
+        # construct lower/upper halfspace
         self.construct_wing(-1, n)
         self.construct_wing(1, n)
 
+
 class NetworkxHexagonal(NetworkxCrystal):
 
+    """
+    A derived class for spatial, planar hexagonal graphs.
+
+    """
+
+    def __init__(self, tiling_factor, periodic=False):
         """
-        A derived class for spatial, planar hexagonal graphs.
+        A constructor for a planar, hexagonal crystal objects, setting default
+        values for the interal graph objects and geometry
+        """
+        super(NetworkxHexagonal, self).__init__()
+        self.hexagonal_grid(tiling_factor, periodic)
+
+    def hexagonal_grid(self, tiling_factor, periodic_bool):
 
         """
+        Set the internal graph as hexagonal grid, using the networkx graph
+        generator.
+        """
 
-        def __init__(self, tiling_factor, periodic=False):
-            """
-            A constructor for a planar, hexagonal crystal objects, setting default values
-             for the interal graph objects and geometry
-            """
-            super(NetworkxHexagonal, self).__init__()
-            self.hexagonal_grid(tiling_factor, periodic)
+        # generate hexagonal grid
+        m = 2*tiling_factor+1
+        n = 2*tiling_factor
+        opt = {
+            'periodic': periodic_bool,
+            'with_positions': True
+        }
+        self.G = nx.hexagonal_lattice_graph(m, n, **opt)
 
-        def hexagonal_grid(self, tiling_factor, periodic_bool):
-
-            """
-            Set the internal graph as hexagonal grid, using the networkx graph generator
-
-            """
-
-            # generate hexagonal grid
-            m = 2*tiling_factor+1
-            n = 2*tiling_factor
-            opt = {
-                'periodic': periodic_bool,
-                'with_positions': True
-            }
-            self.G = nx.hexagonal_lattice_graph(m, n, **opt)
-
-            # set embedding data
-            for n in self.G.nodes():
-                self.G.nodes[n]['pos'] = np.array(self.G.nodes[n]['pos'])
-            
+        # set embedding data
+        for n in self.G.nodes():
+            self.G.nodes[n]['pos'] = np.array(self.G.nodes[n]['pos'])
